@@ -9,7 +9,7 @@ from typing import List, Optional, Tuple
 
 import matplotlib.pyplot as plt
 import pandas as pd
-import typer
+from typer import Typer, Argument, Option
 
 from .functions import demo_df
 from .series import Context, Plot, Series, setup
@@ -57,37 +57,35 @@ def convert_to_label(df: pd.DataFrame, value: str) -> str:
 
 
 def make_column_pairs(
-    df: pd.DataFrame, column_list: List[str]
+    df: pd.DataFrame, column_string: Optional[str]
 ) -> List[Tuple[str, str]]:
     """TODO"""
 
-    if not column_list:
+    if not column_string:
         columns = df.columns.tolist()
         x_column = columns[0]
         y_columns = columns[1:]
         column_pairs = [(x_column, y_column) for y_column in y_columns]
+        return column_pairs
 
-    else:
-        column_list_items = [len(value.split(",")) for value in column_list]
-        if all((item == 1 for item in column_list_items)):
-            # X Y1 Y2 ... YN
-            column_list = [convert_to_label(df, value) for value in column_list]
-            x_column = column_list[0]
-            y_columns = column_list[1:]
-            column_pairs = [(x_column, y_column) for y_column in y_columns]
+    column_pairs = []
+    for column_substring in column_string.split(":"):
+        column_list = column_substring.split(",")
+        if len(column_list) < 2:
+            exit_cli(
+                f"Does not support series without x column yet ({column_substring})"
+            )
 
-        elif all((item == 2 for item in column_list_items)):
-            # X1,Y1 X2,Y2 ... XN,YN
-            column_pairs = []
-            for pair in column_list:
-                x_value, y_value = pair.split(",")
-                x_column = convert_to_label(df, x_value)
-                y_column = convert_to_label(df, y_value)
-                column_pairs.append((x_column, y_column))
+        column_list = [convert_to_label(df, value) for value in column_list]
+        x_column = column_list[0]
+        y_columns = column_list[1:]
+        column_pairs += [(x_column, y_column) for y_column in y_columns]
 
-        else:
-            exit_cli("ERROR")
+    return column_pairs
 
+
+def verify_column_pairs(df: pd.DataFrame, column_pairs: List[Tuple[str, str]]):
+    """TODO"""
     # Verify all column indices are valid
     for x_column, y_column in column_pairs:
         if x_column not in df:
@@ -95,8 +93,6 @@ def make_column_pairs(
         if y_column not in df:
             exit_cli(f"Invalid column: {y_column}")
 
-    return column_pairs
-
 
 def load_series(
     df: pd.DataFrame,
@@ -116,8 +112,7 @@ def load_series(
     cycle = plt.rcParams["axes.prop_cycle"]()
 
     series = [
-        Series(df, x_column, y_column,
-            marker="o", color=next(cycle).get("color"))
+        Series(df, x_column, y_column, marker="o", color=next(cycle).get("color"))
         for x_column, y_column in column_pairs
     ]
 
@@ -125,26 +120,41 @@ def load_series(
 
 
 def run(
-    data_file_path: Path = typer.Argument(default=None, exists=True, dir_okay=False),
-    columns: List[str] = typer.Argument(default=None),
-    data: Optional[List[Path]] = typer.Option(default=None, dir_okay=False),
-    x: Optional[List[str]] = typer.Option(default=None),
-    y: Optional[List[str]] = typer.Option(default=None),
-    title: str = "",
-    xlabel: str = "",
-    ylabel: str = "",
-    context: Context = typer.Option(Context.notebook),
-    head: bool = typer.Option(None, help="Display head of data file."),
-    demo: bool = typer.Option(None, help="Generate demo.png and use it."),
+    data_file_path: Path = Argument(
+        None, exists=True, dir_okay=False, help="File to parse for new series"
+    ),
+    column_string: str = Argument(
+        None, help="Columns of file to parse.  See above for series format."
+    ),
+    files: List[Path] = Option(
+        None,
+        "--file",
+        exists=True,
+        dir_okay=False,
+        help="Additional file(s) to parse for new series",
+    ),
+    columns: List[str] = Option(
+        None,
+        "--col",
+        help="Columns of files to parse for new series.  There should be one --file for each --coll.",
+    ),
+    title: str = Option("", help="Title of plot."),
+    xlabel: str = Option("", help="Label for X Axis."),
+    ylabel: str = Option("", help="Label for Y Axis."),
+    x: Optional[Tuple[float, float]] = Option(None, "-x", help="Range for X Axis."),
+    y: Optional[Tuple[float, float]] = Option(None, "-y", help="Range for Y Axis."),
+    head: bool = Option(None, help="Display head of data file."),
+    demo: bool = Option(None, help="Generate a set of sample series."),
+    context: Context = Option(Context.notebook),
     version: bool = version_option(),
 ) -> None:
     """
         Plot will read the DATA_FILE_PATH and plot the data specified by COLUMNS.
 
         COLUMNS must be of the form
-          X Y1 Y2 ... Yn
+          X,Y1,Y2,...,Yn
         or
-          X1,Y1 X2,Y2 ... Xn,Yn
+          X1,Y1:X2,Y2:...:Xn,Yn
 
         The column value must either be the index of the column (1...N),
         or the name of the column.
@@ -161,24 +171,27 @@ def run(
         1-9    | Toggle Series 1-9 Display
         enter  | Save Plot to png Image
         escape | Exit
+        left   | Pan left
+        right  | Pan right
+        up     | Pan up
+        down   | Pan down
 
     \b
         Holding the left mouse button down and moving the mouse will pan the plot.
         Rolling the mouse wheel up and down will zoom out and in where the mouse is.
     """
-
     df_list = []
 
     if data_file_path:
         df_list.append(load_data(data_file_path))
         title = title or data_file_path.stem.replace("_", " ")
 
-    df_list.extend(load_data(data_file_path) for data_file_path in data)
+    df_list.extend(load_data(data_file_path) for data_file_path in files)
     if not title:
-        title = ", ".join(d.stem.replace("_", " ") for d in data)
+        title = ", ".join(f.stem.replace("_", " ") for f in files)
 
     if demo:
-        df_list = demo_df("demo.dat")
+        df_list = [demo_df("demo.dat")]
         title = title or "Demo"
 
     if not df_list:
@@ -187,16 +200,25 @@ def run(
     if head:
         exit_cli(df_list[0].head(10))  # FIXME - assumes one df
 
+    column_list = [column_string] if column_string else []
+    column_list.extend(iter(columns))
+
     setup(context)
 
-    if x and y:
-        columns = x + y
-
-    column_pairs = make_column_pairs(df_list[0], columns)  # FIXME - assumes one df
-
     series = []
-    for df in df_list:
-        series += load_series(df, column_pairs)
+    if len(column_list) in {0, 1}:
+        df = df_list[0]
+        column_pairs = make_column_pairs(df, column_list[0])
+        verify_column_pairs(df, column_pairs)
+        for df in df_list:
+            series += load_series(df, column_pairs)
+    elif len(column_list) == len(df_list):
+        for df, column_string in zip(df_list, column_list):
+            column_pairs = make_column_pairs(df, column_string)
+            verify_column_pairs(df, column_pairs)
+            series += load_series(df, column_pairs)
+    else:
+        exit_cli("Invalid number of columns")
 
     if len(column_pairs) == 1:
         xlabel, ylabel = column_pairs[0]
@@ -204,13 +226,17 @@ def run(
     plot1 = Plot(title=title, xlabel=xlabel, ylabel=ylabel)
     plot1.add(series)
     plot1.draw()
+    if x:
+        plot1.ax.set_xlim(x[0], x[1])
+    if y:
+        plot1.ax.set_ylim(y[0], y[1])
     plt.show()
 
 
 def main() -> None:
     """Call the app command run"""
 
-    app = typer.Typer(add_completion=False)
+    app = Typer(add_completion=False)
     app.command()(run)
     app()
 
